hart_stats = zeros(1000,250);
hart_preds = zeros(1502,250);
hart_data = zeros(1502,250);

neuk_stats = zeros(1000,250);
neuk_preds = zeros(1502,250);
neuk_data = zeros(1502,250);

load('obliquity_hists.mat')
hart_hists = hart(:,:,5);
neuk_hists = neuk(:,:,5);

hart_means = zeros(1,250);
hart_fracs = zeros(1,250);

neuk_means = zeros(1,250);
neuk_fracs = zeros(1,250);

for i = 1:250
    load(strcat('4hartpred_',num2str(i),'.mat'), 'best_data',...
        'best_pred', 'ksstats');
    hart_stats(:,i) = ksstats;
    hart_preds(:,i) = best_pred';
    hart_data(:,i) = best_data';
    
    temp_hist = hart_hists(i,:);
    hart_means(i) = sum(temp_hist.*(0:90)/sum(temp_hist));
    hart_fracs(i) = sum(temp_hist(41:end)/sum(temp_hist));
    
    load(strcat('4neukpred_',num2str(i),'.mat'), 'best_data',...
        'best_pred', 'ksstats');
    neuk_stats(:,i) = ksstats;
    neuk_preds(:,i) = best_pred';
    neuk_data(:,i) = best_data';
    
    temp_hist = neuk_hists(i,:);
    neuk_means(i) = sum(temp_hist.*(0:90)/sum(temp_hist));
    neuk_fracs(i) = sum(temp_hist(41:end)/sum(temp_hist));
end

%%%%% HEAT MAPS %%%%%
load('latehesperian_4test.mat');
diams = log10(crater_diams);
ors = crater_ors;
lats = crater_lats;

D = log10(4):.1:log10(32);
O = 5:1:85;
L = floor(min(lats)):(max(lats));
L = -90:90;

[dd, oo] = meshgrid(D,O);

fig1 = figure('color',[1 1 1]);
subplot(1,2,1);
[f, xi, bwd] = ksdensity([ors diams], [oo(:),dd(:)]);
contourf(oo, dd, reshape(log10(f/sum(f)),[length(O), length(D)]));
yticks(log10([4 8 16 32 64]));
yticklabels({'4','8','16','32', '64'});
set(gca,'fontsize',9);
xlabel('Azimuth (^o from due North)');
ylabel('Diameter (km)');
c = colorbar;
title(c,'log_{10}(PDF)');
axis([0 90 log10(4) log10(32)]);

subplot(1,2,2);
[oo, ll] = meshgrid(O,L);
[f, xi, bw] = ksdensity([ors lats], [oo(:),ll(:)]);
contourf(oo,ll,reshape(log10(f/sum(f)), [length(L), length(O)]));
set(gca,'fontsize',9);
xlabel('Azimuth (^o from due North)');
ylabel('Latitude (^o)');
c = colorbar;
title(c,'log_{10}(PDF)');
axis([0 90 -90 90]);

fig1.PaperUnits = 'centimeters';
fig1.PaperPosition = [0 0 19 9.5];
print(fig1,'FIG3','-dtiffn','-r500');

%%%%% OBLIQUITY PDFS %%%%%%
fig2 = figure('color',[1 1 1]);
[~,I] = min(hart_stats, [], 2);
hartI = I;
sub1 = subplot(1,2,1);
Colors = lines(3);
set(fig2,'colormap',Colors);
[N, ~] = histcounts(I,.5:250.5);
[~,sorted] = sort(N);
for i = sorted
    temppdf = hart_hists(i,:)./sum(hart_hists(i,:));
    counts = sum(I == i);
    if counts >= 10^1.5
        plot(0:90,temppdf,'color',Colors(floor(2*log10(counts)),:),'linewidth',2.5);
    elseif counts >= 10
        plot(0:90,temppdf,'color',Colors(floor(2*log10(counts)),:),'linewidth',2);
    elseif counts >= 10^.5
        plot(0:90,temppdf,'color',Colors(floor(2*log10(counts)),:),'linewidth',1);
    else
        plot(0:90,temppdf,'color',[.5 .5 .5]);
    end
    hold on
end
c = colorbar;
caxis([0.5, 2]);
set(gca,'fontsize', 9);
xlabel('Obliquity (^o)');
ylabel('Probablity Density');
title(c,'log_{10}(counts)');
title(sub1, 'Hartmann');
axis([0 90 0 .1]);

[~,I] = min(neuk_stats, [], 2);
neukI = I;
sub2 = subplot(1,2,2);
Colors = lines(3);
set(fig2,'colormap',Colors);
[N, ~] = histcounts(I,.5:250.5);
[~,sorted] = sort(N);
for i = sorted
    temppdf = neuk_hists(i,:)./sum(neuk_hists(i,:));
    counts = sum(I == i);
    if counts >= 10^1.5
        plot(0:90,temppdf,'color',Colors(floor(2*log10(counts)),:),'linewidth',2.5);
    elseif counts >= 10
        plot(0:90,temppdf,'color',Colors(floor(2*log10(counts)),:),'linewidth',2);
    elseif counts >= 10^.5
        plot(0:90,temppdf,'color',Colors(floor(2*log10(counts)),:),'linewidth',1);
    else
        plot(0:90,temppdf,'color',[.5 .5 .5]);
    end
    hold on
end
c = colorbar;
caxis([0.5, 2]);
set(gca,'fontsize', 9);
xlabel('Obliquity (^o)');
ylabel('Probablity Density');
title(c,'log_{10}(counts)');
title(sub2, 'Neukum');
axis([0 90 0 .1]);

fig2.PaperUnits = 'centimeters';
fig2.PaperPosition = [0 0 19 9.5];
print(fig2,'FIG8','-dtiffn','-r500');


%%% MEANS AND OVER 40 %%%
fig3 = figure('color',[1 1 1]);
sub1 = subplot(1,2,1);
[f, xi] = ksdensity(hart_means,'BandWidth', 2);
plot(xi,f,'b--','linewidth',1.5);
hold on
[f, xi] = ksdensity(neuk_means,'BandWidth', 2);
plot(xi,f,'r--','linewidth',1.5);
[f, xi] = ksdensity(hart_means(hartI),'BandWidth', 2);
plot(xi,f,'b','linewidth',1.5);
[f, xi] = ksdensity(neuk_means(neukI),'BandWidth', 2);
plot(xi,f,'r','linewidth',1.5);

sortedpriorharts = sort(hart_means);
hartconfbound = sortedpriorharts(floor(length(sortedpriorharts)*.95));
plot([hartconfbound hartconfbound], [0 .07], 'b--');

sortedpriorneuks = sort(neuk_means);
neukconfbound = sortedpriorneuks(floor(length(sortedpriorneuks)*.95));
plot([neukconfbound neukconfbound], [0 .07], 'r--');

sortedpriorharts = sort(hart_means(hartI));
hartconfbound = sortedpriorharts(floor(length(sortedpriorharts)*.95));
plot([hartconfbound hartconfbound], [0 .07], 'b');

sortedpriorneuks = sort(neuk_means(neukI));
neukconfbound = sortedpriorneuks(floor(length(sortedpriorneuks)*.95));
plot([neukconfbound neukconfbound], [0 .07], 'r');
set(gca,'fontsize', 9);
xlabel('Mean Obliquity (^o)');
ylabel('Probablity Density');

sub2 = subplot(1,2,2);
[f, xi] = ksdensity(hart_fracs,0:.01:1,'BandWidth', .05);
plot(xi,f/sum(f),'b--','linewidth',1.5);
hold on
[f, xi] = ksdensity(neuk_fracs,0:.01:1,'BandWidth', .05);
plot(xi,f/sum(f),'r--','linewidth',1.5);
[f, xi] = ksdensity(hart_fracs(hartI),0:.01:1,'BandWidth', .05);
plot(xi,f/sum(f),'b','linewidth',1.5);
[f, xi] = ksdensity(neuk_fracs(neukI),0:.01:1,'BandWidth', .05);
plot(xi,f/sum(f),'r','linewidth',1.5);

sortedpriorharts = sort(hart_fracs);
hartconfbound = sortedpriorharts(floor(length(sortedpriorharts)*.95));
plot([hartconfbound hartconfbound], [0 .06], 'b--');

sortedpriorneuks = sort(neuk_fracs);
neukconfbound = sortedpriorneuks(floor(length(sortedpriorneuks)*.95));
plot([neukconfbound neukconfbound], [0 .06], 'r--');

sortedpriorharts = sort(hart_fracs(hartI));
hartconfbound = sortedpriorharts(floor(length(sortedpriorharts)*.95));
plot([hartconfbound hartconfbound], [0 .06], 'b');

sortedpriorneuks = sort(neuk_fracs(neukI));
neukconfbound = sortedpriorneuks(floor(length(sortedpriorneuks)*.95));
plot([neukconfbound neukconfbound], [0 .06], 'r');
set(gca,'fontsize', 9);
xlabel('Fraction of Time with \epsilon > 40^o');
ylabel('Probablity Density');

fig3.PaperUnits = 'centimeters';
fig3.PaperPosition = [0 0 10 9.5];
print(fig3,'FIG9','-dtiffn','-r500');


%%% DATA PLOT %%%
bootstraps = zeros(1000,81);
for i = 1:1000
    temp = datasample(crater_ors, length(crater_ors));
    [f, xi] = ksdensity(temp, (5:85),'BandWidth',5);
    bootstraps(i,:) = f/sum(f);
end

fig4 = figure('color', [1 1 1]);
sortedboots = sort(bootstraps, 1);
xx = [(5:85),fliplr(5:85)];
yy = [sortedboots(1,:),fliplr(sortedboots(end,:) )]';
patch(xx,yy,0,'FaceAlpha',0.3,'EdgeAlpha',0.3);
hold on
[f, xi] = ksdensity(crater_ors, (5:85),'BandWidth',5);
plot(5:85, f/sum(f),'LineWidth',1.5);
xlabel('Azimuth (^o from due North)');
set(gca,'fontsize',9);
ylabel('Probability Density');
axis([0 90 .002 0.025]);

box on
[f, xi] = ksdensity(hart_preds(:,245), (5:85),'BandWidth',5);
plot(5:85, f/sum(f),'k--','LineWidth',1.5);

legend('Full Bootstrapped Range','Raw Data','Example Fit');

fig4.PaperUnits = 'centimeters';
fig4.PaperPosition = [0 0 19 9.5];
print(fig4,'FIG4','-dtiffn','-r500');

